module generic_ram #(
    parameter int AW = 10,
    parameter int DW = 32,
    localparam int BW = DW / 8,
    localparam int Depth = 2**AW
) (
    input  logic          clk,
    input  logic          cen0,
    input  logic [AW-1:0] addr0,
    output logic [DW-1:0] rdata0,
    input  logic          cen1,
    input  logic          wen1,
    input  logic [AW-1:0] addr1,
    input  logic [DW-1:0] wdata1,
    input  logic [BW-1:0] wstrb1,
    output logic [DW-1:0] rdata1
);

  logic [DW-1:0] mem[Depth];
  logic [DW-1:0] wmask;

  assign wmask = {{8{wstrb1[3]}}, {8{wstrb1[2]}}, {8{wstrb1[1]}}, {8{wstrb1[0]}}};

  always @(posedge clk) begin
    if (cen0) begin
      rdata0 <= mem[addr0];
    end

    if (cen1) begin
      if (wen1) begin
        mem[addr1] <= wdata1 & wmask;
      end else begin
        rdata1 <= mem[addr1];
      end
    end
  end


endmodule
